
#ifndef ___clutter_marshal_MARSHAL_H__
#define ___clutter_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:BOXED (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:1) */
extern void _clutter_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* BOOLEAN:BOXED,INT,INT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:2) */
extern void _clutter_marshal_BOOLEAN__BOXED_INT_INT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* BOOLEAN:OBJECT,BOOLEAN (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:3) */
extern void _clutter_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);

/* BOOLEAN:OBJECT,BOXED,DOUBLE (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:4) */
extern void _clutter_marshal_BOOLEAN__OBJECT_BOXED_DOUBLE (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* BOOLEAN:OBJECT,DOUBLE (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:5) */
extern void _clutter_marshal_BOOLEAN__OBJECT_DOUBLE (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* BOOLEAN:OBJECT,ENUM (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:6) */
extern void _clutter_marshal_BOOLEAN__OBJECT_ENUM (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* BOOLEAN:OBJECT,FLAGS (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:7) */
extern void _clutter_marshal_BOOLEAN__OBJECT_FLAGS (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* BOOLEAN:STRING,UINT,FLAGS (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:8) */
extern void _clutter_marshal_BOOLEAN__STRING_UINT_FLAGS (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

/* BOOLEAN:OBJECT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:9) */
extern void _clutter_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* BOOLEAN:OBJECT,FLOAT,FLOAT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:10) */
extern void _clutter_marshal_BOOLEAN__OBJECT_FLOAT_FLOAT (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);

/* BOXED:UINT,UINT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:11) */
extern void _clutter_marshal_BOXED__UINT_UINT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* DOUBLE:VOID (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:12) */
extern void _clutter_marshal_DOUBLE__VOID (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* UINT:VOID (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:13) */
extern void _clutter_marshal_UINT__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* VOID:BOOLEAN (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:14) */
#define _clutter_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:BOXED (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:15) */
#define _clutter_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* VOID:BOXED,FLAGS (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:16) */
extern void _clutter_marshal_VOID__BOXED_FLAGS (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:INT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:17) */
#define _clutter_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT64,INT64,FLOAT,BOOLEAN (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:18) */
extern void _clutter_marshal_VOID__INT64_INT64_FLOAT_BOOLEAN (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
                                                              const GValue *param_values,
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);

/* VOID:INT,INT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:19) */
extern void _clutter_marshal_VOID__INT_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:FLOAT,FLOAT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:20) */
extern void _clutter_marshal_VOID__FLOAT_FLOAT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:INT,INT,INT,INT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:21) */
extern void _clutter_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:OBJECT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:22) */
#define _clutter_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,FLAGS (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:23) */
extern void _clutter_marshal_VOID__OBJECT_FLAGS (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:OBJECT,FLOAT,FLOAT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:24) */
extern void _clutter_marshal_VOID__OBJECT_FLOAT_FLOAT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* VOID:OBJECT,FLOAT,FLOAT,FLAGS (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:25) */
extern void _clutter_marshal_VOID__OBJECT_FLOAT_FLOAT_FLAGS (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:OBJECT,PARAM (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:26) */
extern void _clutter_marshal_VOID__OBJECT_PARAM (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:OBJECT,POINTER (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:27) */
extern void _clutter_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:OBJECT,UINT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:28) */
extern void _clutter_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:POINTER (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:29) */
#define _clutter_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:STRING,BOOLEAN (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:30) */
extern void _clutter_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:STRING,BOOLEAN,BOOLEAN (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:31) */
extern void _clutter_marshal_VOID__STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* VOID:STRING,INT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:32) */
extern void _clutter_marshal_VOID__STRING_INT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:UINT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:33) */
#define _clutter_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT

/* VOID:UINT,STRING,UINT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:34) */
extern void _clutter_marshal_VOID__UINT_STRING_UINT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:UINT,UINT (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:35) */
extern void _clutter_marshal_VOID__UINT_UINT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:VOID (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:36) */
#define _clutter_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:STRING,INT,POINTER (/usr/src/ports/mingw64-i686-clutter1.0/mingw64-i686-clutter1.0-1.24.2-1.noarch/src/clutter-1.24.2/clutter/clutter-marshal.list:37) */
extern void _clutter_marshal_VOID__STRING_INT_POINTER (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

G_END_DECLS

#endif /* ___clutter_marshal_MARSHAL_H__ */

